/*
 * symfunc.h - the "symmetric function coefficients" for the Virasoro
 * conditions
 *
 * The purpose of this file is to provide the functions
 *
 *   symfunc (x,k,i) = the (k+1-i)-th elemetary symmetric function in the
 *                     numbers x,x+1,...,x+k
 * where x is a rational number, and k>=-1 and 0<=i<=k+1 are integers.
 *
 * In other words, we have
 *
 *   product (s+x+i,i=0..k) = sum (symfunc (x,k,i)*s^i,i=0..k).
 *
 * These numbers are needed for the Virasoro conditions. As the numbers are
 * needed very often and their computation (especially for large i and k) is
 * quite complicated, we store the numbers in a database, similarly to the
 * Gromov-Witten invariants.
 *
 * The computation is done by recursion on i via the relations
 *
 *   symfunc (x,k,i) = sum ((x+j)*symfunc (x+j+1,k-1-j,i-j),j=0..infty)
 *
 * (the sum is of course finite, as we need to have i>=0 and k>=-1).
 *
 */

#ifndef __SYMFUNC_H__
#define __SYMFUNC_H__

#include <stdlib.h>
#include <iostream.h>
#include <assert.h>

#include "poly.h"
#include "database.h"

extern database SYMdbm; // the database to store the numbers

rational symfunc (const rational& , int, int);

#endif

